import { RecordSubscription, UnsubscribeFunc } from 'pocketbase';
import { AccountsListResponse, AccountsRecord, AccountsResponse, Collections } from '../types/pocketbase.types';
import { PocketbaseService } from './pocketbase.service';

const COLLECTION = PocketbaseService.getApi().collection(Collections.Accounts);
const VIEW = PocketbaseService.getApi().collection(Collections.AccountsList);

export class AccountService {
  public static async getAccount(accountNumber: string): Promise<AccountsResponse> {
    return COLLECTION.getFirstListItem(`accountNumber = "${accountNumber}"`);
  }
  public static async checkIn(accountNumber: string): Promise<AccountsResponse> {
    const account = await this.getAccount(accountNumber);
    return COLLECTION.update(account.id, { lastCheckIn: new Date() });
  }
  public static async getAccounts(): Promise<AccountsListResponse<number, string>[]> {
    return VIEW.getFullList();
  }
  public static getAccountsByCompanyId(companyId: string): Promise<AccountsListResponse<number, string>[]> {
    return COLLECTION.getFullList({ filter: `company.id = "${companyId}"` });
  }
  public static async addAccount(account: AccountsRecord): Promise<AccountsResponse> {
    return COLLECTION.create(account, { $cancelKey: `${account.firstName}.${account.lastName}.${account.grade}` });
  }

  public static async subscribeToAccountChanges(
    callback: (data: RecordSubscription<AccountsResponse>)=> void,
  ): Promise<UnsubscribeFunc> {
    return await COLLECTION.subscribe<AccountsResponse>('*', (data) => {
      callback(data);
    });
  }
}